@@ -494,8 +494,16 @@ class Database(object):
 			return r3sponse.success(f"Successfully checked the content of {self.path}.")
 		# load & decrypt.
 		def load(self):
+			def unpack(content):
+				if " " not in content:
+					raise ValueError("Encrypted format is incorrectly packed.")
+				format = ""
+				for i in content:
+					if i not in [" "]: format += i
+					else: break
+				return format, content[len(format):]
 			try:
-				format, content = Files.load(str(self.path)).split(" ")
+				format, content = unpack(Files.load(self.path))
 			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
 			response = self.aes.decrypt(content.encode())
 			if not response.success: return response
@@ -527,7 +535,7 @@ class Database(object):
 				return r3sponse.error("The data object is not loaded yet, you must call content.load() first.")
 			if self.format in ["list", "dict"]:
 				try:
-					content = json.dumps(self.content)
+					content = json.dumps(Formats.denitialize(self.content))
 				except Exception as e: return r3sponse.error(f"Failed to dump content {self.path}, {e}.")
 			elif self.format in ["str", "int", "float"]:
 				content = str(self.content)
